==> okta-sdk-api-21.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner.JSON_PROPERTY_ATTRIBUTES,
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner.JSON_PROPERTY_VALUE })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value_attributeValues_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-02-24T22:29:38.763116-06:00[America/Chicago]", comments = "Generator version: 7.11.0")
public class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ATTRIBUTES = "attributes";
    private SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes attributes;

    public static final String JSON_PROPERTY_VALUE = "value";
    private String value;

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner() {
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner attributes(
            SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes attributes) {

        this.attributes = attributes;
        return this;
    }

    /**
     * Get attributes
     *
     * @return attributes
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes getAttributes() {
        return attributes;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributes(SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes attributes) {
        this.attributes = attributes;
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner value(String value) {

        this.value = value;
        return this;
    }

    /**
     * The actual value of the attribute
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The actual value of the attribute")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(String value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner saMLPayLoadDataAssertionClaimsValueAttributeValuesInner = (SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner) o;
        return Objects.equals(this.attributes, saMLPayLoadDataAssertionClaimsValueAttributeValuesInner.attributes)
                && Objects.equals(this.value, saMLPayLoadDataAssertionClaimsValueAttributeValuesInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributes, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner {\n");
        sb.append("    attributes: ").append(toIndentedString(attributes)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}

==> okta-sdk-api-24.0.0-sources.jar: src/gen/java/main/com/okta/sdk/resource/model/SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner.java <==
package com.okta.sdk.resource.model;

import java.util.Objects;
import java.util.Arrays;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonTypeName;
import com.fasterxml.jackson.annotation.JsonValue;
import com.okta.sdk.resource.model.SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes;
import java.io.Serializable;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.fasterxml.jackson.annotation.JsonTypeName;
import io.swagger.annotations.ApiModelProperty;
import io.swagger.annotations.ApiModel;

/**
 * SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner
 */
@JsonPropertyOrder({ SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner.JSON_PROPERTY_ATTRIBUTES,
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner.JSON_PROPERTY_VALUE })
@JsonTypeName("SAMLPayLoad_data_assertion_claims_value_attributeValues_inner")
@jakarta.annotation.Generated(value = "org.openapitools.codegen.languages.JavaClientCodegen", date = "2025-07-28T10:14:57.946459+05:30[Asia/Kolkata]", comments = "Generator version: 7.11.0")
public class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner implements Serializable {

    private static final long serialVersionUID = 1L;

    public static final String JSON_PROPERTY_ATTRIBUTES = "attributes";
    private SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes attributes;

    public static final String JSON_PROPERTY_VALUE = "value";
    private String value;

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner() {
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner attributes(
            SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes attributes) {

        this.attributes = attributes;
        return this;
    }

    /**
     * Get attributes
     *
     * @return attributes
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "")
    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes getAttributes() {
        return attributes;
    }

    @JsonProperty(JSON_PROPERTY_ATTRIBUTES)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setAttributes(SAMLPayLoadDataAssertionClaimsValueAttributeValuesInnerAttributes attributes) {
        this.attributes = attributes;
    }

    public SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner value(String value) {

        this.value = value;
        return this;
    }

    /**
     * The actual value of the attribute
     *
     * @return value
     **/
    @javax.annotation.Nullable
    @ApiModelProperty(value = "The actual value of the attribute")
    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)

    public String getValue() {
        return value;
    }

    @JsonProperty(JSON_PROPERTY_VALUE)
    @JsonInclude(value = JsonInclude.Include.USE_DEFAULTS)
    public void setValue(String value) {
        this.value = value;
    }

    @Override
    public boolean equals(Object o) {
        if (this == o) {
            return true;
        }
        if (o == null || getClass() != o.getClass()) {
            return false;
        }
        SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner saMLPayLoadDataAssertionClaimsValueAttributeValuesInner = (SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner) o;
        return Objects.equals(this.attributes, saMLPayLoadDataAssertionClaimsValueAttributeValuesInner.attributes)
                && Objects.equals(this.value, saMLPayLoadDataAssertionClaimsValueAttributeValuesInner.value);
        // ;
    }

    @Override
    public int hashCode() {
        return Objects.hash(attributes, value);
    }

    @Override
    public String toString() {
        StringBuilder sb = new StringBuilder();
        sb.append("class SAMLPayLoadDataAssertionClaimsValueAttributeValuesInner {\n");
        sb.append("    attributes: ").append(toIndentedString(attributes)).append("\n");
        sb.append("    value: ").append(toIndentedString(value)).append("\n");
        sb.append("}");
        return sb.toString();
    }

    /**
     * Convert the given object to string with each line indented by 4 spaces (except the first line).
     */
    private String toIndentedString(Object o) {
        if (o == null) {
            return "null";
        }
        return o.toString().replace("\n", "\n    ");
    }

}
